@@ -228,6 +228,11 @@ class H2OXGBoostMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasMonotoneCons
         return H2OTypeConverters.scala2DArrayToPython2DArray(value)
 
 
+    def getScalePosWeight(self):
+        value = self._java_obj.getScalePosWeight()
+        return value
+
+
     def getNfolds(self):
         value = self._java_obj.getNfolds()
         return value
